@@ -1,4 +1,6 @@
 package POE::Component::Win32::EventLog;
+$POE::Component::Win32::EventLog::VERSION = '1.26';
+#ABSTRACT: A POE component that provides non-blocking access to Win32::EventLog.
 
 # Author: Chris "BinGOs" Williams
 #
@@ -14,9 +16,6 @@ use POE 0.38 qw(Wheel::Run Filter::Line Filter::Reference);
 use Win32;
 use Win32::EventLog;
 use Carp qw(carp croak);
-use vars qw($VERSION);
-
-$VERSION = '1.24';
 
 our %functions = ( qw(backup Backup read Read getoldest GetOldest getnumber GetNumber clear Clear report Report) );
 
@@ -179,7 +178,7 @@ sub child_stdout {
     $self->{queuing} = 0;
     $kernel->yield( '_flush_queue' );
   }
-  undef;  
+  undef;
 }
 
 sub _flush_queue {
@@ -209,7 +208,7 @@ sub _shutdown {
 }
 
 sub _subprocess {
-  binmode(STDIN); binmode(STDOUT); 
+  binmode(STDIN); binmode(STDOUT);
   my ($source,$system,$dontresolveuser) = splice @_, 0, 3;
   my $raw;
   my $size = 4096;
@@ -290,12 +289,21 @@ sub _lookupaccountsid {
 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::Win32::EventLog - A POE component that provides non-blocking access to Win32::EventLog.
 
+=head1 VERSION
+
+version 1.26
+
 =head1 SYNOPSIS
 
   use POE qw(Component::Win32::EventLog);
@@ -473,20 +481,21 @@ In the event of an error occurring this will be defined. It is an arrayref which
 
 This module will only work on Win32. But you guessed that already :)
 
-=head1 AUTHOR
-
-Chris 'BinGOs' Williams
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams.
-
-This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
-
 =head1 SEE ALSO
 
 L<POE>
 
 L<Win32::EventLog>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
